aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/install/helper/config.php
diff options
context:
space:
mode:
authorTristan Darricau <tristan.darricau@sensiolabs.com>2016-02-16 00:06:52 +0100
committerTristan Darricau <tristan.darricau@sensiolabs.com>2016-02-16 00:06:52 +0100
commitd0ce6a18df2172a6e9baf1f1c2802efb30b25323 (patch)
tree478bf6c878bacec7c4e60832e0af7d106bd52e52 /phpBB/phpbb/install/helper/config.php
parent00d71d854cb844cba7755a2e8adfa4217dbc0ef0 (diff)
parent6debd9a1bea4ee69a06eac43cc6b2f856f601604 (diff)
downloadforums-d0ce6a18df2172a6e9baf1f1c2802efb30b25323.tar
forums-d0ce6a18df2172a6e9baf1f1c2802efb30b25323.tar.gz
forums-d0ce6a18df2172a6e9baf1f1c2802efb30b25323.tar.bz2
forums-d0ce6a18df2172a6e9baf1f1c2802efb30b25323.tar.xz
forums-d0ce6a18df2172a6e9baf1f1c2802efb30b25323.zip
Merge pull request #4171 from CHItA/ticket/14462
[ticket/14462] Try to prevent timeouts in the installer * CHItA/ticket/14462: [ticket/14462] Not show timeout messages in convertors [ticket/14462] Make timeout error translateable [ticket/14462] Update ordering in install db config [ticket/14462] Fix comments [ticket/14462] Fix tests [ticket/14462] Fix CS and typo [ticket/14462] Set instance of db driver for database access using global [ticket/14462] Fix installation in tests [ticket/14462] Refactor tasks to be more modular [ticket/14462] Further speed improvements
Diffstat (limited to 'phpBB/phpbb/install/helper/config.php')
-rw-r--r--phpBB/phpbb/install/helper/config.php18
1 files changed, 13 insertions, 5 deletions
diff --git a/phpBB/phpbb/install/helper/config.php b/phpBB/phpbb/install/helper/config.php
index f58925899b..fad6749019 100644
--- a/phpBB/phpbb/install/helper/config.php
+++ b/phpBB/phpbb/install/helper/config.php
@@ -96,7 +96,8 @@ class config
$this->system_data = array();
$this->progress_data = array(
'last_task_module_name' => '', // Stores the service name of the latest finished module
- 'last_task_name' => '', // Stores the service name of the latest finished task
+ 'last_task_module_index' => 0, // Stores the index of the latest finished module
+ 'last_task_index' => 0, // Stores the index of the latest finished task
'max_task_progress' => 0,
'current_task_progress' => 0,
'_restart_points' => array(),
@@ -187,21 +188,23 @@ class config
/**
* Saves the latest executed task
*
* @param string $task_service_name Name of the installer task service
*/
- public function set_finished_task($task_service_name)
+ public function set_finished_task($task_service_index)
{
- $this->progress_data['last_task_name'] = $task_service_name;
+ $this->progress_data['last_task_index'] = $task_service_index;
}
/**
* Set active module
*
* @param string $module_service_name Name of the installer module service
+ * @param int $module_service_index Index of the installer module service
*/
- public function set_active_module($module_service_name)
+ public function set_active_module($module_service_name, $module_service_index)
{
$this->progress_data['last_task_module_name'] = $module_service_name;
+ $this->progress_data['last_task_module_index'] = $module_service_index;
}
/**
@@ -391,6 +394,11 @@ class config
*/
public function set_finished_navigation_stage($nav_path)
{
+ if (isset($this->navigation_data['finished']) && in_array($nav_path, $this->navigation_data['finished']))
+ {
+ return;
+ }
+
$this->navigation_data['finished'][] = $nav_path;
}
@@ -187,21 +188,23 @@ class config
* Saves the latest executed task
*
- * @param string $task_service_name Name of the installer task service
+ * @param int $task_service_index Index of the installer task service in the module
*/